<?php
namespace Modules\Fornecimento\Modules\AutorizacaoFornecimento\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services\TimeLineService;

class TimelineController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "timeline";
    private $lastApproved;

    public function __construct($crudService, $parameterBag, $dataSourceManager,TimeLineService $service ) {
        $this->dataSourceManager = $dataSourceManager;
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->service = $service;
    }

    public function retornaTimelineFormatada(Request\Filter $request, Response $response) {
        try {

            $filterCriteria = $request->getFilterCriteria();

            $arrayToSelect = array();
            foreach($filterCriteria->getConditions() as $filter) {
                $arrayToSelect[$filter['columnName']] = $filter['value'];
            }

            $NRDEMANDA = $filterCriteria->getConditions()[2]['value'];
            $aprovadores = $this->service->getAprovadores($arrayToSelect);

            $dataSet = self::prepareResponseDataset($aprovadores, $NRDEMANDA);

            $response->addDataSet(new DataSet('timeline', $dataSet));

        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function prepareResponseDataset($aprovadores, $NRDEMANDA) {
        $dataSet = array();
        $demanda = $this->service->getDemanda($NRDEMANDA);
        $this->lastApproved = false;
        foreach ($aprovadores as $aprovador) {
            $idAprovado = $this->service->getIdAprovado($aprovador['CDOPERAPROV'], $demanda['NRAUTOFORN']);
            if($aprovador['VRAPROVCMP'] < $demanda['VRTOTALAF'] || !empty($idAprovado)) {
                $state = self::defineApprovalState($aprovador);
                array_push($dataSet, $this->service->returnMountedArray($aprovador, $state));
            }
        }
        return $dataSet;
    }
    
    public function defineApprovalState ($aprovador) {
        if($aprovador['IDAPROVADO'] == 'APROVADO') {
            $state = 'checked';
        }
        else if($this->lastApproved == false) {
            $state = $aprovador['IDAPROVADO'] == 'PENDENTE' ? 'exclamation' : 'error';
            $this->lastApproved = true;
        }
        else {
            $state = "block";
        }
        return $state;
    }

}