/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8435_SUPSTP_VERIFICA_COTACAO                                         */
/*                                                                            */
/* Descrio:                                                                 */
/*  - Verifica se aquela cotao pode ou no ser marcada na hora da apurao  */
/*    dos melhores preos, levando en conta:                                  */
/*                                  o valor mnimo  de AF por fornecedor      */
/*                                  a quantidade mnima por fornecedor        */
/*                                  a quantidade mnima por produto/forncedor */
/*                                                                            */
/* Criao:                                                                   */
/*    06/08/2002 - Joo Fernando dos Reis Corra                              */
/*                                                                            */
/******************************************************************************/
CREATE OR REPLACE PROCEDURE VERIFICA_COTACAO
(
   P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
   P_CDFORNECED   IN FORNECEDOR.CDFORNECED%TYPE,
   P_CDPRODUTO    IN PRODUTO.CDPRODUTO%TYPE,
   P_IDAPURPRXFOR IN PARASUPRI.IDAPURPRXFOR%TYPE,
   P_VRPRECUNIAP  IN ITMAPURPREC.VRPRECUNIAP%TYPE,
   P_QTACOMP      IN ITMAPURPREC.QTACOMP%TYPE,
   P_MARCACOL     OUT VARCHAR2
)
IS
   V_QTMINAUTFOT FORNECEDOR.QTMINAUTFOT%TYPE;
   V_VRMINAUTFOR FORNECEDOR.VRMINAUTFOR%TYPE;
   V_QTMINAF     PRODFORN.QTMINAF%TYPE;
BEGIN
   P_MARCACOL := 'S';
   IF SUBSTR(P_IDAPURPRXFOR, 1, 1) = 'S' AND P_MARCACOL = 'S' THEN
      SELECT NVL(MAX(VRMINAUTFOR), 0) INTO V_VRMINAUTFOR
      FROM FORNECEDOR
      WHERE CDFORNECED = P_CDFORNECED;
      IF P_VRPRECUNIAP < V_VRMINAUTFOR THEN
         P_MARCACOL := 'N';
      END IF;
   END IF;
   IF SUBSTR(P_IDAPURPRXFOR, 2, 1) = 'S' AND P_MARCACOL = 'S' THEN
      SELECT NVL(MAX(QTMINAUTFOT), 0) INTO V_QTMINAUTFOT
      FROM FORNECEDOR
      WHERE CDFORNECED = P_CDFORNECED;
      IF P_QTACOMP < V_QTMINAUTFOT THEN
         P_MARCACOL := 'N';
      END IF;
   END IF;
   IF SUBSTR(P_IDAPURPRXFOR, 3, 1) = 'S' AND P_MARCACOL = 'S' THEN
      SELECT NVL(MAX(QTMINAF), 0) INTO V_QTMINAF
      FROM PRODFORN
      WHERE CDFORNECED = P_CDFORNECED AND
            CDPRODUTO  = P_CDPRODUTO;
      IF P_QTACOMP < V_QTMINAF THEN
         P_MARCACOL := 'N';
      END IF;
   END IF;
END;
/